!!! warning "Under Construction"

    This section is currently under construction.

## Purpose
The purpose of this documentation is to provide a comprehensive guide to understanding and working with knowledge graphs within the context of BioCypher.  It aims to explain the fundamental concepts of knowledge graphs and how they are represented in BioCypher.


## Catalog

- [About Adapters](adapters.md)
- [About Ontologies](ontologies.md)
- [Schema Configuration: Philosophy and Concepts](schema-config-philosophy.md)

<!-- TODO there are "basics-knowledge-graphs.md" and
"knowledge-graph-biocypher.md" to still consider, fill in, etc. I am not
particularly convinced we need to (or are able to, in fact) explain very basic
things without knowing the user's background. Some knowledge should be assumed,
and we can also link to external resources (even very general ones, like
wikipedia) for further reading. -->
